# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   python_stduy
# FileName:      readexcel.py
# Author:       xxxxxxx
# Datetime:     2023/8/7 18:46
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl

from API_third.common.readini import ReadIni
from API_third.common.readjson import readjson
from API_third.data_config.settings import *


class ReadExcel:

    def __init__(self):
        self.readini = ReadIni()
        case_data_path = self.readini.get_file_path(CASE)
        expect_data_path = self.readini.get_file_path(EXPECT)
        sql_data_path = self.readini.get_file_path(SQL)

        self.case_data_dict = readjson(case_data_path)
        self.expect_data_dict = readjson(expect_data_path)
        self.sql_data_dict = readjson(sql_data_path)

        excelpath = self.readini.get_file_path(EXCEL)
        wb = openpyxl.load_workbook(excelpath)
        table = self.readini.get_table_name(TABLE)
        self.ws = wb[table]

    def __get_excel_values(self,column,row):
        value = self.ws[str(column)+str(row)].value
        if value is None:
            return None
        elif value.strip():
            return value.strip()

    def get_modulename(self,row):
        return self.__get_excel_values(MODULE,row)

    def get_interfacename(self,row):
        return self.__get_excel_values(API,row)

    def get_casetitle(self,row):
        return self.__get_excel_values(TITLE,row)

    def get_caselevel(self,row):
        return self.__get_excel_values(LEVEL,row)

    def get_method(self,row):
        return self.__get_excel_values(METHOD,row)

    def get_url(self,row):
        return self.readini.get_host(HOST)+self.__get_excel_values(PATH,row)


    def case_mime(self,row):
        value = self.__get_excel_values(MIME,row)
        if value:
            return value.lower()

    def get_casedata(self,row):
        casedata_key = self.__get_excel_values(CASEDATA,row)
        if casedata_key:
            modulename = self.get_modulename(row)
            interfacename = self.get_interfacename(row)
            return self.case_data_dict[modulename][interfacename][casedata_key]

    def get_expectdata(self,row):

        expect_key = self.__get_excel_values(EXPECTDATA, row)
        if expect_key:
            modulename = self.get_modulename(row)
            interfacename = self.get_interfacename(row)
            return self.expect_data_dict[modulename][interfacename][expect_key]


    def get_sqltype(self,row):
        value = self.__get_excel_values(SQLTYPE,row)
        if value:
            return value.lower()

    def get_sqlsentence(self,row):
        sql_key = self.__get_excel_values(SQLSENTENCE,row)
        if sql_key:
            modulename = self.get_modulename(row)
            interfacename = self.get_interfacename(row)
            return self.sql_data_dict[modulename][interfacename][sql_key]


    def get_updatakey(self,row):

        return self.__get_excel_values(UPDATEKEY,row)

    def get_data(self):
        lists = []
        for row in range(2,self.ws.max_row+1):
            module = self.get_modulename(row)
            interface = self.get_interfacename(row)
            title = self.get_casetitle(row)
            level = self.get_caselevel(row)
            method = self.get_method(row)
            url = self.get_url(row)
            mime = self.case_mime(row)
            data = self.get_casedata(row)
            expect = self.get_expectdata(row)
            sqltype = self.get_sqltype(row)
            sqlsentence = self.get_sqlsentence(row)
            updatakey = self.get_updatakey(row)
            lists.append([module, interface, title, level, method, url, mime, data, expect, sqltype, sqlsentence, updatakey])

        return lists


if __name__ == '__main__':
    readexcel = ReadExcel()
    print(readexcel.get_data())
